rm(list=ls())
graphics.off()

library(raster)
library(rasterVis)
library(maps)
library(maptools)
library(dismo)
library(fields)

source('funcoes/southammap.r')
source('funcoes/shaded.r')
source('funcoes/shaded.raster.r')
source('funcoes/palette.tglobal.r')
source('funcoes/plot.vector.r')

## Abrindo o netcdf e plotando com o pacote raster

#++++++++++++++++++++++++++++++++++++++++++++++
r <- raster('dados/reanalise/omega_xy.nc')

plot(r, col = tim.colors(255))

plot(r, col = tim.colors(255), inter = TRUE)
map('world', add = TRUE)

map('world')
map("world", fill=TRUE, col="gray")
map.axes()

omega <- rotate(r)

graphics.off()
plot(omega, col = tim.colors(255), inter = TRUE)
map('world', add = TRUE, lwd = 2)

#++++++++++++++++++++++++#
# LENDO OS DEMAIS NETCDF #
#++++++++++++++++++++++++#

r <- raster('dados/reanalise/temp_xy.nc')
temp <- rotate(r)

r <- raster('dados/reanalise/ur_xy.nc')
ur <- rotate(r)

r <- raster('dados/reanalise/u_xy.nc')
u <- rotate(r)

r <- raster('dados/reanalise/v_xy.nc')
v <- rotate(r)

#++++++++++++++++++++++++++++++#
# ALGUNS CALCULOS COM O RASTER #
#++++++++++++++++++++++++++++++#

es <- 6.11*exp(17.67*temp/(temp+243.5))
e <- ur*es/100

graphics.off()
plot(es, inter = TRUE, main = 'es', xlab = 'Longitude', ylab = 'Latitude')
map('world', add = TRUE)

graphics.off()
plot(e, inter = TRUE, main = 'e', xlim = c(-80,-10), ylim = c(-60,0))
southammap('dados/mapas')

#+++++++++++++++++++++++++#
# PLOTS MAIS SOFISTICADOS #
#+++++++++++++++++++++++++#

#PLOT 1
graphics.off()
filledContour(omega)
map('world', add = TRUE)

#PLOT 2
graphics.off()
filledContour(omega, plot.axes = {map('world', add = TRUE)})

#PLOT 3
graphics.off()
filledContour(omega, nlevels = 25, color = tim.colors,
              plot.axes = {map('world', add = TRUE)
                           axis(side = 1, cex.axis = 1)
                           axis(side = 2, cex.axis = 1)})

#PLOT 4
graphics.off()
filledContour(omega, nlevels = 25, color = tim.colors,
              plot.axes = {
                           map('world', add = TRUE)
                           axis(side = 1, cex.axis = 1)
                           axis(side = 2, cex.axis = 1)
                           grid(lty="dotted",col="black")
                           contour(omega, add=TRUE)})

#PLOT 5
graphics.off()
filledContour(omega, nlevels = 255, color = tim.colors, xlim = c(-60,-10), ylim = c(-50,0),
              plot.axes = {
                          southammap("dados/mapas")
                          axis(side = 1, cex.axis = 1)
                          axis(side = 2, cex.axis = 1)
                          grid(lty="dotted",col="black")
                          contour(rr, add=TRUE)})

#PLOT 6
graphics.off()
shaded.raster(omega, nlevels = 255, color = cm.colors,
              plot.axes = {
                          map('world', add = TRUE)
                          axis(side = 1, cex.axis = 1)
                          axis(side = 2, cex.axis = 1)
                          grid(lty="dotted",col="black")})


#PLOT 7
graphics.off()
shaded.raster(temp, nlevels = 255, color = palette.tglobal,
              plot.axes = {
                map('world', add = TRUE)
                axis(side = 1, cex.axis = 1)
                axis(side = 2, cex.axis = 1)
                grid(lty="dotted",col="black")})

#PLOT 8
graphics.off()
shaded.raster(temp, nlevels = 255, color = palette.tglobal,
              plot.axes = {
                map('world', add = TRUE)
                axis(side = 1, cex.axis = 1)
                axis(side = 2, cex.axis = 1)
                grid(lty="dotted",col="black")
                plot.vector(u,v,int=2, xpd = FALSE, arrow.ex=.08, length=.07, lwd=1)
                })

#PLOT 9
mag <- sqrt(u^2+v^2)
graphics.off()
shaded.raster(mag, nlevels = 255, color = tim.colors, #xlim = c(-60,-10), ylim = c(-50,0),
              plot.axes = {
                map('world', add = TRUE, lwd=2)
                axis(side = 1, cex.axis = 1)
                axis(side = 2, cex.axis = 1)
                grid(lty="dotted",col="black")
                plot.vector(u,v,int=2, xpd = FALSE, arrow.ex=.08, length=.07, lwd=1)
              })

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++

#PLOT 9
graphics.off()
levelplot(temp, layers = 1, contour = TRUE)

#PLOT 10
graphics.off()
p <- levelplot(temp, layers = 1, contour = TRUE)
p+layer(map('world', add = FALSE))
p+layer(map('world', add = TRUE))

#PLOT 11
graphics.off()
p <- levelplot(tempr, layers = 1, margin = FALSE, contour = TRUE)
p+layer(map('world', add = FALSE))
p+layer(map('world', add = TRUE))

#PLOT 12
graphics.off()
myTheme <- rasterTheme(region=tim.colors(255))
p <- levelplot(temp, layers = 1, margin = FALSE, contour = FALSE, par.settings=myTheme, cuts = 50)
p+layer(map('world', add = FALSE))
p+layer(map('world', add = TRUE))

#PLOT 13
graphics.off()
proj <- CRS('+proj=latlon +ellps=WGS84')
mapworld <- readShapeLines('dados/mapas/admin98_li_shp/admin98.shp', proj4string=proj)
p <- levelplot(temp, layers=1, FUN.margin=median)
p + layer(sp.lines(mapworld, lwd=0.8, col='darkgray'))

#PLOT 14
graphics.off()
mapsp <- readShapeLines('dados/mapas/municios/municip07.shp', proj4string=proj)
mapst <- readShapeLines('dados/mapas/estados/estadosl_2007.shp', proj4string=proj)
p <- levelplot(temp, layers=1, margin = FALSE, xlim = c(-54,-43), ylim = c(-26,-19))
pl <- p + layer(sp.lines(mapst, lwd=1.2, col='black'))
pl + layer(sp.lines(mapsp, lwd=0.8, col='darkgray'))

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++
  
e <- extent(-90,-25,-70,10)
r1 <- crop(temp, e)

g <- gmap(r1, type = 'hybrid')

r2 <- projectRaster(r1, g)
xylon <- Mercator(c(-90,-25))
xylat <- Mercator(c(-70,10))
xy <- extent(xylon[1],xylon[2],xylat[1],xylat[2])

graphics.off()

plot(g, inter = TRUE, ext = xy)
plot(r2, alpha=0.7, add = TRUE, ext = xy, col = rev(heat.colors(255)))
contour(r2, lwd=2, levels = (1:17)*2, col = rev(heat.colors(17)), ext = xy, add = TRUE)
pt <- cbind(-50, -30)
mpt <- Mercator(pt)
points(mpt, col='light blue', pch='+', cex=2)
