rm(list=ls())
graphics.off()

require(ncdf)
library(raster)
library(rasterVis)
library(maps)
library(maptools)
library(fields)

source('funcoes/southammap.r')
source('funcoes/shaded.r')
source('funcoes/shaded.raster.r')
source('funcoes/palette.tglobal.r')
source('funcoes/plot.vector.r')

r <- brick('dados/reanalise/q_xyt.nc')
q <- rotate(r)
plot(q)

graphics.off()
levelplot(q)

proj <- CRS('+proj=latlon +ellps=WGS84')
mapworld <- readShapeLines('dados/mapas/10m-admin-0-boundary-lines-map-units/ne_10m_admin_0_boundary_lines_map_units.shp', proj4string=proj)
graphics.off()
p <- levelplot(q)
p + layer(sp.lines(mapworld, lwd=0.8, col='darkgray'))

#++++++++++++++++++++++++++++++++++++++++++++++++
nc <- open.ncdf('dados/reanalise/temp_xyzt.nc')

lat.nc <- get.var.ncdf(nc = nc, varid = 'lat')
lon.nc <- get.var.ncdf(nc = nc, varid = 'lon')
lev.nc <- get.var.ncdf(nc = nc, varid = 'level')
timearr <- get.var.ncdf(nc = nc, varid = 'time')

un = nc$var[['air']]$dim[[4]]$units
startTime = substr(un, 13, 30)
startTime = strptime(startTime, "%Y-%m-%d %H:%M:%OS", tz = 'GMT')
time <- startTime+as.numeric(timearr)*3600-2*86400 #retrocede dois dias

loni <- -90
lonf <- -10
lati <- -70 
latf <- 10

lon <- c(loni, lonf)+360.
lat <- c(lati, latf)
lev <- 850

cut.lon <- lon.nc[lon.nc >= lon[1] & lon.nc <= lon[2]]
cut.lat <- lat.nc[lat.nc >= lat[1] & lat.nc <= lat[2]]
cut.lev <- lev

pos.loni <- match(min(cut.lon), lon.nc)
pos.lati <- match(max(cut.lat), lat.nc) #<=== CUIDADO A LATITUDE HE INVERTIDA
pos.levi <- match(min(cut.lev), lev.nc)

vtype <- nc$var[['air']]
varsize <- vtype$varsize
ndims <- vtype$ndims
ntime <- varsize[ndims]

start <- rep(1, ndims)
start[1] <- pos.loni
start[2] <- pos.lati
start[3] <- pos.levi

nlon <- length(cut.lon)
nlat <- length(cut.lat)
nlev <- length(cut.lev)

count <- varsize
count[1] <- nlon
count[2] <- nlat
count[3] <- nlev

var <- get.var.ncdf(nc, vtype, start = start, count = count)

revlat.var <- array(NA, c(nlat, nlon, ntime))  #<===== dimensao da matriz tranposta

for (t in 1:ntime) {
  revlat.var[,,t] <- t(var[,nlat:1,t]) #<===== transposta da matriz com inversao de latitude
}

temp <- list()
temp$lon <- cut.lon
temp$lat <- rev(cut.lat)
temp$lev <- cut.lev
temp$time <- time
temp$nc <- revlat.var

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

proj <- "+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"
r <- brick(temp$nc, xmn=min(temp$lon), xmx=max(temp$lon), ymn=min(temp$lat), ymx=max(temp$lat), crs = proj)
T <- setZ(r, temp$time)
layerNames(T) <- format(temp$time, "%B")
levelplot(T)

graphics.off()
levelplot(T, layer = 1, margin = FALSE, main = layerNames(T)[1])

graphics.off()
levelplot(T, layer = 6, margin = FALSE, main = layerNames(T)[6])

graphics.off()
levelplot(T, layer = 1:6)

